==> wiredash-0.2.0.tar.gz: lib/src/common/translation/l10n/messages_es.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Capturar pantalla";
  @override
  String get captureSkip => "Saltar pantalla";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navegar a la pantalla a la pantalla que le gustaría adicionar para capturar";
  @override
  String get captureSpotlightNavigateTitle => "Navegar";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Pantalla capturada! Dibuje libremente para resaltar las áreas afectadas en la pantalla.";
  @override
  String get captureSpotlightScreenCapturedTitle => "Dibuje";
  @override
  String get captureTakeScreenshot => "Realizar captura de pantalla";
  @override
  String get feedbackBack => "Regresar";
  @override
  String get feedbackCancel => "Cancelar";
  @override
  String get feedbackModeBugMsg =>
      "Informe este error para que lo enviemos a nuestro repositorio";
  @override
  String get feedbackModeBugTitle => "Reporte un error";
  @override
  String get feedbackModeImprovementMsg =>
      "Tiene alguna idea que podría mejorar nuestra app? Nos encanta escucharla!";
  @override
  String get feedbackModeImprovementTitle =>
      "Solicitar una nueva funcionalidad";
  @override
  String get feedbackModePraiseMsg =>
      "Déjenos saber lo que más le gustó de nuestra app, cree que la podemos mejorar más?";
  @override
  String get feedbackModePraiseTitle => "Enviar aplauso";
  @override
  String get feedbackSave => "Grabar";
  @override
  String get feedbackSend => "Enviar retroalimentación";
  @override
  String get feedbackStateEmailMsg =>
      "Si desea recibir notificaciones a cerca de sus comentarios por favor escriba su email a continuación";
  @override
  String get feedbackStateEmailTitle => "Mantenerse involucrado";
  @override
  String get feedbackStateFeedbackMsg =>
      "Por favor proveer información detallada para ayudarle de la mejor manera";
  @override
  String get feedbackStateIntroMsg =>
      "Nos interesa conocer su opinión acerca de la app. Que le gustaría realizar?";
  @override
  String get feedbackStateIntroTitle => "Saludos 👋";
  @override
  String get feedbackStateSuccessCloseMsg =>
      "Muchas gracias por sus comentarios!";
  @override
  String get feedbackStateSuccessCloseTitle => "Cerrar ventana";
  @override
  String get feedbackStateSuccessMsg =>
      "Eso es todo. Muchas gracias por ayudarnos a construir una mejor app";
  @override
  String get feedbackStateSuccessTitle => "Gracias ✌️";
  @override
  String get inputHintEmail => "Escriba su email";
  @override
  String get inputHintFeedback => "Sus comentarios";
  @override
  String get validationHintEmail =>
      "Por favor escriba un email válido o deje este campo vacío";
  @override
  String get validationHintFeedbackEmpty => "Por favor escriba sus comentarios";
  @override
  String get validationHintFeedbackLength =>
      "Sus comentarios son demasiado extensos";
  @override
  String get feedbackStateFeedbackTitle => "Sus comentarios 🖊";
}

==> wiredash-0.4.0.tar.gz: lib/src/common/translation/l10n/messages_es.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Capturar pantalla";
  @override
  String get captureSkip => "Saltar pantalla";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navegar a la pantalla a la pantalla que le gustaría adicionar para capturar";
  @override
  String get captureSpotlightNavigateTitle => "Navegar";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Pantalla capturada! Dibuje libremente para resaltar las áreas afectadas en la pantalla.";
  @override
  String get captureSpotlightScreenCapturedTitle => "Dibuje";
  @override
  String get captureTakeScreenshot => "Realizar captura de pantalla";
  @override
  String get feedbackBack => "Regresar";
  @override
  String get feedbackCancel => "Cancelar";
  @override
  String get feedbackModeBugMsg =>
      "Informe este error para que lo enviemos a nuestro repositorio";
  @override
  String get feedbackModeBugTitle => "Reporte un error";
  @override
  String get feedbackModeImprovementMsg =>
      "¿Tiene alguna idea que podría mejorar nuestra app? ¡Nos encantaría escucharla!";
  @override
  String get feedbackModeImprovementTitle =>
      "Solicitar una nueva funcionalidad";
  @override
  String get feedbackModePraiseMsg =>
      "Déjenos saber lo que más le gustó de nuestra app, cree que la podemos mejorar más?";
  @override
  String get feedbackModePraiseTitle => "Enviar aplauso";
  @override
  String get feedbackSave => "Guardar";
  @override
  String get feedbackSend => "Enviar retroalimentación";
  @override
  String get feedbackStateEmailMsg =>
      "Si desea recibir notificaciones a cerca de sus comentarios por favor escriba su email a continuación";
  @override
  String get feedbackStateEmailTitle => "Mantenerse involucrado";
  @override
  String get feedbackStateFeedbackMsg =>
      "Por favor proveer información detallada para ayudarle de la mejor manera";
  @override
  String get feedbackStateIntroMsg =>
      "Nos interesa conocer su opinión acerca de la app. ¿Qué le gustaría realizar?";
  @override
  String get feedbackStateIntroTitle => "Saludos 👋";
  @override
  String get feedbackStateSuccessCloseMsg =>
      "Muchas gracias por sus comentarios!";
  @override
  String get feedbackStateSuccessCloseTitle => "Cerrar ventana";
  @override
  String get feedbackStateSuccessMsg =>
      "Eso es todo. Muchas gracias por ayudarnos a construir una mejor app";
  @override
  String get feedbackStateSuccessTitle => "Gracias ✌️";
  @override
  String get inputHintEmail => "Escriba su email";
  @override
  String get inputHintFeedback => "Sus comentarios";
  @override
  String get validationHintEmail =>
      "Por favor escriba un email válido o deje este campo vacío";
  @override
  String get validationHintFeedbackEmpty => "Por favor escriba sus comentarios";
  @override
  String get validationHintFeedbackLength =>
      "Sus comentarios son demasiado extensos";
  @override
  String get feedbackStateFeedbackTitle => "Sus comentarios 🖊";
  @override
  String get firstPenLabel => "";
  @override
  String get secondPenLabel => "";
  @override
  String get thirdPenLabel => "";
  @override
  String get fourthPenLabel => "";
  @override
  String get companyLogoLabel => "";
  @override
  String get undoButtonLabel => "";
  @override
  String get firstPenSelected => "";
  @override
  String get secondPenSelected => "";
  @override
  String get thirdPenSelected => "";
  @override
  String get fourthPenSelected => "";
}
